Learn R Programming

simpleaffy (version 2.48.0)

qc.get.probes: Retrieve QC probeset names for the current array type

Description

Get the names of probesets used to calculate 3'/5' ratios for the current array type. qc.get.spikes is used to set the spike probe names (i.e. bioB, bioC, etc.)

Usage

qc.get.probes()
 qc.get.probe(name)
 qc.add.probe(name,probeset)

Arguments

name
A name for the given probeset. By default, this is the probeset identifier
probeset
A probeset ID

Value

  • A character array of probeset IDs, or the requested probeset ID, as appropriate.

References

http://bioinformatics.picr.man.ac.uk/

See Also

setQCEnvironment qc.get.spikes

Examples

Run this code
setQCEnvironment("hgu133plus2cdf")
  qc.get.probes()
  qc.add.probe("my.name","a.probesetid_at")
  qc.add.probe("another.name","another.probesetid_at")
  qc.get.probes()

Run the code above in your browser using DataLab