Learn R Programming

simpleaffy (version 2.48.0)

qc.get.ratios: Retrieve pairs of probesets used for calculating 3'/5' ratios

Description

Get the names of the qc probesets used to define the 3'/5' ratios.

Usage

qc.get.ratios()
 qc.get.ratio(name)
 qc.add.ratio(name,probeset1,probeset2)

Arguments

name
A name for the given ratio calculation (such as gapdh3/5)
probeset1
A probeset ID
probeset2
A probeset ID

Value

  • A list, each element with a name like gapdh3/5 and comprising of a two-element character vector of probeset IDs.

References

http://bioinformatics.picr.man.ac.uk/

See Also

setQCEnvironment qc.get.probes

Examples

Run this code
setQCEnvironment("hgu133plus2cdf")
  qc.get.ratios()
  qc.add.ratio("a.name","probeset1.id","probeset2.id")
  qc.get.ratio("a.name")

Run the code above in your browser using DataLab