Learn R Programming

simpleaffy (version 2.48.0)

qc.ok: Has simpleaffy's QC environment been set up?

Description

Simpleaffy requires a definition file describing the qc probes, spikes, alpha values, etc. for the array of interest. This is used to initialize the QC environment for the array (usually implicitly within the qc function), by a call to setQCEnvironment. This function can be used to check if the qc environment has been set up for the current session

Usage

qc.ok()

Arguments

Value

  • True or False

References

http://bioinformatics.picr.man.ac.uk/

See Also

setQCEnvironment qc qc.have.params cdfName

Examples

Run this code
qc.ok()
  setQCEnvironment("hgu133plus2cdf")
  qc.ok()

Run the code above in your browser using DataLab