For a pairwise comparison the ordering of the first group of replicates
b.order
For a pairwise comparison the ordering of the second group of replicates
method
What method should be used to calculate the average for the fold-change - can be either "logged","unlogged","median"
Value
An object of class PairComp
Details
Given an ExpressionSet object, generate quick stats for pairwise
comparisons between a pair of experimental groups. If a.order and
b.order are specified then a paired sample t-test will be conducted
between the groups, with the arrays in each group sorted according to
the ordering specified.
The fold-changes are computed from the average values across
replicates. By default this is done using the mean of the unlogged
values. The parameter, method allows the mean of the logged values or
the median to be used instead. T-tests are always computed with the
logged data.